@@ -26,6 +26,7 @@ import os
 import sys
 
 import msgpack
+import json
 from tornado.options import define, options
 from tornado.options import parse_command_line, parse_config_file
 
@@ -37,7 +38,7 @@ AppGroup = "Application"
 CocaineGroup = "Cocaine"
 ActionGroup = "Actions"
 
-POSSIBLE_ACTIONS = ('upload', 'deploy', 'start', 'stop', 'listing', 'undeploy')
+POSSIBLE_ACTIONS = ('upload', 'deploy', 'start', 'stop', 'listing', 'undeploy', 'info')
 API_VERSION = 1.1
 
 
@@ -228,6 +229,18 @@ def listing():
         exit(1)
 
 
+@Dispatcher.attach("info")
+def info():
+    log.info("Fetching a list of your applications")
+    try:
+        s = Service("flow@main", host=options.host, port=options.port)
+        listing0 = s.enqueue("info", gen_task(None)).get()
+        print(json.dumps(listing0, indent=2))
+    except Exception as err:
+        log.error(err)
+        exit(1)
+
+
 def main():
     HOME_CONFIG_PATH = os.path.expanduser("~/.cocaine.conf")
     if os.path.exists(".cocaine.conf"):
